@@ -1,6 +1,4 @@
 /***************************************************************************
- *
- * $Header: /usr/local/cvsroot/utils/ytree/dirwin.c,v 1.25 2010/02/28 13:11:53 werner Exp $
  *
  * Funktionen zur Handhabung des DIR-Windows
  *
@@ -178,8 +176,8 @@ static void PrintDirEntry(WINDOW *win,
 		 break;
     case MODE_2 :
                  (void)GetAttributes(de_ptr->stat_struct.st_mode, attributes);
-                 owner_name_ptr = GetPasswdName(de_ptr->stat_struct.st_uid);
-                 group_name_ptr = GetGroupName(de_ptr->stat_struct.st_gid);
+                 owner_name_ptr = GetDisplayPasswdName(de_ptr->stat_struct.st_uid);
+                 group_name_ptr = GetDisplayGroupName(de_ptr->stat_struct.st_gid);
                  if( owner_name_ptr == NULL )
                  {
                     (void)sprintf(owner,"%d",(int)de_ptr->stat_struct.st_uid);
@@ -190,14 +188,14 @@ static void PrintDirEntry(WINDOW *win,
                      (void) sprintf( group, "%d", (int) de_ptr->stat_struct.st_gid );
                      group_name_ptr = group;
                  }
-                 if ((line_buffer = (char *) malloc(39)) == NULL)
+                 if ((line_buffer = (char *) malloc(40)) == NULL)
                  {
                     ERROR_MSG("malloc() Failed*Abort");
                     exit(1);
                  }
-                 (void) strcpy( format, "%10s %8d  %-8s %-8s");
+                 (void) strcpy( format, "%12u  %-12s %-12s");
                  (void) sprintf( line_buffer, format, 
-                                 attributes, 
+                                 /*attributes, */
                                  de_ptr->stat_struct.st_ino, 
                                  owner_name_ptr,         
                                  group_name_ptr);
@@ -746,6 +744,7 @@ void HandleShowAll(DirEntry *dir_entry, DirEntry *start_dir_entry, BOOL *need_ds
 	} else {
 	    dir_entry->big_window  = TRUE;
 	    dir_entry->global_flag = TRUE;
+	    dir_entry->tagged_flag = FALSE;
 	    dir_entry->start_file  = 0;
 	    dir_entry->cursor_pos  = 0;
 	}
@@ -1071,15 +1070,15 @@ int HandleDirWindow(DirEntry *start_dir_entry)
                      {
 		       if( !RenameDirectory( dir_entry, new_name ) )
 		       {
-			 /* Rename OK */
-			 /*-----------*/
+		         /* Rename OK */
+		         /*-----------*/
 		         BuildDirEntryList( start_dir_entry );
                          DisplayTree( dir_window, statistic.disp_begin_pos, 
-				      statistic.disp_begin_pos + statistic.cursor_pos 
-				    );
+		                      statistic.disp_begin_pos + statistic.cursor_pos 
+			            );
 		         DisplayAvailBytes();
 		         dir_entry = dir_entry_list[statistic.disp_begin_pos + statistic.cursor_pos].dir_entry;
-                       }
+		       }
 		     }
 		     need_dsp_help = TRUE;
 		     break;
@@ -1193,13 +1192,11 @@ int KeyF2Get(DirEntry *start_dir_entry,
 	     int cursor_pos,
              char *path)
 {
-  DirEntry  *dir_entry;
   int ch;
   int result = -1;
   int win_width, win_height;
 
 
-  dir_entry = start_dir_entry;
   GetMaxYX(f2_window, &win_height, &win_width);
   MapF2Window();
   DisplayTree( f2_window, disp_begin_pos, disp_begin_pos + cursor_pos );
