@@ -1,6 +1,4 @@
 /***************************************************************************
- *
- * $Header: /usr/local/cvsroot/utils/ytree/disp.c,v 1.20 2003/08/31 11:11:00 werner Exp $
  *
  * Menue-Geruest anzeigen
  *
@@ -18,25 +16,25 @@ static void DisplayVersion(void);
 
 
 static char *mask[] = {
-"5--------------------2",
-"|FILE:               |",
-"6--------------------7",
-"|DISK:               |",
-"| Avail              |",
-"6--------------------7",
-"|DISK Statistics     |",
-"|[Total]               |",
-"| Files:             |",
-"| Bytes:             |",
-"|[Matching]            |",
-"| Files:             |",
-"| Bytes:             |",
-"|[Tagged]              |",
-"| Files:             |",
-"| Bytes:             |",
-"|[Current Directory]   |",
-"|                    |",
-"| Bytes:             |"
+"5-----------------------2",
+"|FILE:                  |",
+"6-----------------------7",
+"|DISK:                  |",
+"| Avail                 |",
+"6-----------------------7",
+"|DISK Statistics        |",
+"|[Total]                  |",
+"| Files:                |",
+"| Bytes:                |",
+"|[Matching]               |",
+"| Files:                |",
+"| Bytes:                |",
+"|[Tagged]                 |",
+"| Files:                |",
+"| Bytes:                |",
+"|[Current Directory]      |",
+"|                       |",
+"| Bytes:                |"
 };
 
 
@@ -51,10 +49,10 @@ static char *logo[] = {
                         "#####                                     "
 		      };
 
-static char *extended_line = "| |                    |";
+static char *extended_line = "| |                       |";
 
 
-static char *last_line = "3-8--------------------4";
+static char *last_line = "3-8-----------------------4";
 static char *first_line ="1-5";
 
 
@@ -247,12 +245,12 @@ void DisplayMenu(void)
 
   for( y=1; y <= (int)(sizeof(mask) / sizeof(mask[0])); y++){
     PrintOptions( stdscr, y, 0, "|");
-    PrintOptions( stdscr, y, COLS - 22 , mask[y-1] );
+    PrintOptions( stdscr, y, COLS - 25 , mask[y-1] );
   }
   for( ; y < LINES - 4; y++ )
     PrintMenuLine( stdscr, y, 0, extended_line );
-  PrintLine( stdscr, DIR_WINDOW_HEIGHT + 2, 0, "6-7", COLS - 22 );
-  PrintLine( stdscr, 1, 0, first_line, COLS - 22);    
+  PrintLine( stdscr, DIR_WINDOW_HEIGHT + 2, 0, "6-7", COLS - 25 );
+  PrintLine( stdscr, 1, 0, first_line, COLS - 25);    
   PrintMenuLine( stdscr, y, 0, last_line );
 
   l = sizeof(logo) / sizeof(logo[0]);
@@ -277,7 +275,7 @@ void DisplayMenu(void)
 void SwitchToSmallFileWindow(void)
 { 
   werase( file_window );
-  PrintLine( stdscr, DIR_WINDOW_HEIGHT + 2, 0, "6-7", COLS - 22 );
+  PrintLine( stdscr, DIR_WINDOW_HEIGHT + 2, 0, "6-7", COLS - 25 );
   file_window = small_file_window;
   RefreshWindow( stdscr );
 }
@@ -372,9 +370,9 @@ static void PrintMenuLine(WINDOW *win, int y, int x, char *line)
   }
   buffer[0] = line[0];
   if (p == 0)
-     p = COLS - 22;
+     p = COLS - 25;
   else
-     p = COLS - 24;
+     p = COLS - 27;
   for(i=1; i < p; i++)
       buffer[i] = line[1];
   (void) strncpy( &buffer[i], &line[2], l - i );
