@@ -1,6 +1,4 @@
 /***************************************************************************
- *
- * $Header: /usr/local/cvsroot/utils/ytree/filewin.c,v 1.33 2008/07/09 21:41:58 werner Exp $
  *
  * Funktionen zur Handhabung des FILE-Windows
  *
@@ -65,6 +63,7 @@ static void SilentTagWalkTaggedFiles( int (*fkt) (/* ??? */),
 			           WalkingPackage *walking_package
 			          );
 static void RereadWindowSize(DirEntry *dir_entry);
+static void ListJump( DirEntry * dir_entry, char *str );
 
 
 
@@ -180,7 +179,7 @@ static void BuildFileEntryList(DirEntry *dir_entry){
     file_entry_list = NULL;
   }
   if( !dir_entry->global_flag )  {
-     /* ... fuer !ANSI-Systeme ... */
+     /* ... for !ANSI-Systeme ... */
      /*----------------------------*/
      if( dir_entry->matching_files == 0 )    {
         file_entry_list = NULL;
@@ -499,7 +498,7 @@ static void RemoveFileEntry(int entry_no)
 
   SetFileMode( file_mode ); /* recalc */
 
-  file_count--; /* kein realloc */
+  file_count--; /* no realloc */
 }
 
 
@@ -572,7 +571,7 @@ static void PrintFileEntry(int entry_no, int y, int x, unsigned char hilight, in
   char type_of_file = ' ';
 
 
-  ef_window_width = window_width - 2; /* Effektive Window-Weite */
+  ef_window_width = window_width - 2; /* Effektive Window-Width */
 
   (reverse_sort) ? (justify='+') : (justify='-');
 
@@ -683,17 +682,17 @@ static void PrintFileEntry(int entry_no, int y, int x, unsigned char hilight, in
 		  }
 		  else
 		  {
-		    /* Leer-Eintrag */
-		    /*--------------*/
+		    /* Empty Entry */
+		    /*-------------*/
 
-		    (void) sprintf( format, "%%-%ds", max_filename_len + 38 );
+		    (void) sprintf( format, "%%-%ds", max_filename_len + 42 );
 		    (void) sprintf( line_buffer, format, "" );
 		  }
 
 		  if( max_linkname_len ) 
-		    pos_x = x * (max_filename_len + max_linkname_len + 44); 
+		    pos_x = x * (max_filename_len + max_linkname_len + 47); 
 		  else                   
-		    pos_x = x * (max_filename_len + 40); 
+		    pos_x = x * (max_filename_len + 43); 
 		  break;
     
     case MODE_2 : if( fe_ptr )
@@ -702,8 +701,8 @@ static void PrintFileEntry(int entry_no, int y, int x, unsigned char hilight, in
 		                          attributes
 				        );
 		        
-                    owner_name_ptr = GetPasswdName(fe_ptr->stat_struct.st_uid);
-                    group_name_ptr = GetGroupName(fe_ptr->stat_struct.st_gid);
+                    owner_name_ptr = GetDisplayPasswdName(fe_ptr->stat_struct.st_uid);
+                    group_name_ptr = GetDisplayGroupName(fe_ptr->stat_struct.st_gid);
 		      
 		    if( owner_name_ptr == NULL )
 		    {
@@ -719,7 +718,7 @@ static void PrintFileEntry(int entry_no, int y, int x, unsigned char hilight, in
                     if( S_ISLNK( fe_ptr->stat_struct.st_mode ) )
 		    {
 #ifdef HAS_LONGLONG
-                      (void) sprintf( format, "%%c%%c%%%c%ds %%10s %%7lld %%-8s %%-8s -> %%-%ds",
+                      (void) sprintf( format, "%%c%%c%%%c%ds %%10lld %%-12s %%-12s -> %%-%ds",
                                       justify,
 			              max_filename_len,
 			              max_linkname_len
@@ -728,14 +727,13 @@ static void PrintFileEntry(int entry_no, int y, int x, unsigned char hilight, in
 				      (fe_ptr->tagged) ? TAGGED_SYMBOL : ' ',
 				      type_of_file,
 				      fe_ptr->name,
-				      attributes,
 				      (LONGLONG)fe_ptr->stat_struct.st_ino,
 				      owner_name_ptr,
 				      group_name_ptr,
 				      sym_link_name
 				    );
 #else
-                      (void) sprintf( format, "%%c%%c%%%c%ds %%10s %%5d  %%-8s  %%-8s -> %%-%ds",
+                      (void) sprintf( format, "%%c%%c%%%c%ds %%8u  %%-12s  %%-12s -> %%-%ds",
                                       justify,
 			              max_filename_len,
 			              max_linkname_len
@@ -744,7 +742,6 @@ static void PrintFileEntry(int entry_no, int y, int x, unsigned char hilight, in
 				      (fe_ptr->tagged) ? TAGGED_SYMBOL : ' ',
 				      type_of_file,
 				      fe_ptr->name,
-				      attributes,
 				      (int)fe_ptr->stat_struct.st_ino,
 				      owner_name_ptr,
 				      group_name_ptr,
@@ -755,7 +752,7 @@ static void PrintFileEntry(int entry_no, int y, int x, unsigned char hilight, in
 		    else
 		    {
 #ifdef HAS_LONGLONG
-                      (void) sprintf( format, "%%c%%c%%%c%ds %%10s %%7lld %%-8s %%-8s",
+                      (void) sprintf( format, "%%c%%c%%%c%ds %%10lld %%-12s %%-12s",
                                       justify,
 			              max_filename_len
 				      );
@@ -763,13 +760,12 @@ static void PrintFileEntry(int entry_no, int y, int x, unsigned char hilight, in
 				      (fe_ptr->tagged) ? TAGGED_SYMBOL : ' ',
 				      type_of_file,
 				      fe_ptr->name,
-				      attributes,
 				      (LONGLONG)fe_ptr->stat_struct.st_ino,
 				      owner_name_ptr,
 				      group_name_ptr
 				    );
 #else
-                      (void) sprintf( format, "%%c%%c%%%c%ds %%10s %%5d  %%-8s  %%-8s",
+                      (void) sprintf( format, "%%c%%c%%%c%ds %%8u  %%-12s  %%-12s",
                                       justify,
 			              max_filename_len
 				      );
@@ -777,7 +773,6 @@ static void PrintFileEntry(int entry_no, int y, int x, unsigned char hilight, in
 				      (fe_ptr->tagged) ? TAGGED_SYMBOL : ' ',
 				      type_of_file,
 				      fe_ptr->name,
-				      attributes,
 				      (int)fe_ptr->stat_struct.st_ino,
 				      owner_name_ptr,
 				      group_name_ptr
@@ -788,17 +783,17 @@ static void PrintFileEntry(int entry_no, int y, int x, unsigned char hilight, in
 	          }
 		  else
 		  {
-		    /* Leer-Eintrag */
-		    /*--------------*/
+		    /* Empty-Entry */
+		    /*-------------*/
 
-		    (void) sprintf( format, "%%-%ds", max_filename_len + 37 );
+		    (void) sprintf( format, "%%-%ds", max_filename_len + 38 );
 		    (void) sprintf( line_buffer, format, "" );
 		  }
 
 		  if( max_linkname_len ) 
-                    pos_x = x * (max_filename_len + max_linkname_len + 41);
+                    pos_x = x * (max_filename_len + max_linkname_len + 43);
 		  else                   
-                    pos_x = x * (max_filename_len + 37);
+                    pos_x = x * (max_filename_len + 39);
 		  break;
     
     case MODE_3 : if( fe_ptr )
@@ -815,8 +810,8 @@ static void PrintFileEntry(int entry_no, int y, int x, unsigned char hilight, in
                   }
 		  else
 		  {
-		    /* Leer-Eintrag */
-		    /*--------------*/
+		    /* Empty-Entry */
+		    /*-------------*/
 
 		    (void) sprintf( format, "%%-%ds", max_filename_len + 2 );
 		    (void) sprintf( line_buffer, format, "" );
@@ -863,10 +858,10 @@ static void PrintFileEntry(int entry_no, int y, int x, unsigned char hilight, in
 		  }
 		  else
 		  {
-		    /* Leer-Eintrag */
-		    /*--------------*/
+		    /* Empty-Entry */
+		    /*-------------*/
 
-		    (void) sprintf( format, "%%-%ds", max_filename_len + 40 );
+		    (void) sprintf( format, "%%-%ds", max_filename_len + 39 );
 		    (void) sprintf( line_buffer, format, "" );
 		  }
 
@@ -885,10 +880,10 @@ static void PrintFileEntry(int entry_no, int y, int x, unsigned char hilight, in
 		  }
 		  else
 		  {
-		    /* Leer-Eintrag */
-		    /*--------------*/
+		    /* Empty-Entry */
+		    /*-------------*/
 
-		    (void) sprintf( format, "%%-%ds", max_userview_len + 1 );
+		    (void) sprintf( format, "%%-%ds", max_userview_len );
 		    (void) sprintf( line_buffer, format, "" );
 		  }
 		  pos_x = x * (max_userview_len + 1);
@@ -896,15 +891,15 @@ static void PrintFileEntry(int entry_no, int y, int x, unsigned char hilight, in
 
   }
 
-  /* Zeile ausgeben */
-  /*----------------*/
+  /* display line */
+  /*--------------*/
 
-  n = strlen( line_buffer );
+  n = StrVisualLength( line_buffer );
   
   if( n <= ef_window_width )
   {
-    /* Zeile passt komplett */
-    /*----------------------*/
+    /* line fits */
+    /*-----------*/
 
     hide_left = 0;
     hide_right = 0;
@@ -912,13 +907,13 @@ static void PrintFileEntry(int entry_no, int y, int x, unsigned char hilight, in
   }
   else
   {
-    /* Passt nicht; start_x benutzen */
+    /* ... does not fit; use start_x */
     /*-------------------------------*/
     
     if( n > ( start_x + ef_window_width ) )
-      line_ptr = &line_buffer[start_x];
+      line_ptr = &line_buffer[start_x];  /* TODO: UTF-8 */
     else
-      line_ptr = &line_buffer[n - ef_window_width];
+      line_ptr = &line_buffer[n - ef_window_width];  /* TODO: UTF-8 */
     hide_left = start_x;
     hide_right = n - start_x - ef_window_width;
     line_ptr[ef_window_width] = '\0';
@@ -2135,6 +2130,7 @@ int HandleFileWindow(DirEntry *dir_entry)
 			    
                           DisplayAvailBytes();		       
 			  
+			  
 			  DisplayFiles( dir_entry, 
 					dir_entry->start_file, 
 					dir_entry->start_file + dir_entry->cursor_pos,
@@ -2424,8 +2420,8 @@ int HandleFileWindow(DirEntry *dir_entry)
 			  /* Rename OK */
 			  /*-----------*/
 
-			  /* Struktur hat sich (evtl.) veraendert */
-			  /*--------------------------------------*/
+			  /* Maybe structure has changed... */
+			  /*--------------------------------*/
 
 			  BuildFileEntryList( de_ptr );
 		          
@@ -2626,14 +2622,14 @@ int HandleFileWindow(DirEntry *dir_entry)
 		      need_dsp_help = TRUE;
 		      break;
     
-      case 'S' & 0x1F :		/* --crb3 31dec03	*/
+      case 'S' & 0x1F :
                       if( !IsMatchingTaggedFiles() )
                       {
                         beep();
                       }
 		      else if( mode != DISK_MODE && mode != USER_MODE )
 		      {
-			MESSAGE( "I am sorry*^S not supported in Archive-mode" );
+			MESSAGE( "Feature not available in archives." );
 		      }
 		      else
 		      {
@@ -2651,14 +2647,18 @@ int HandleFileWindow(DirEntry *dir_entry)
 			{
 			  refresh();
 			  endwin();
+			  SuspendClock();
+			 
 			  walking_package.function_data.execute.command = command_line;
                           SilentTagWalkTaggedFiles( ExecuteCommand,
 					            &walking_package
 					          );
 			  RefreshWindow( file_window ); 
-			  
+
 			  HitReturnToContinue();
 
+			  InitClock();
+
 			  DisplayFiles( dir_entry, 
 					dir_entry->start_file, 
 					dir_entry->start_file + dir_entry->cursor_pos,
@@ -2732,6 +2732,11 @@ int HandleFileWindow(DirEntry *dir_entry)
       case LOGIN_ESC :
 		      break;
 
+      case KEY_F(12):
+      		      ListJump(dir_entry, "");
+		      need_dsp_help = TRUE;
+		      break;
+
       default:        beep();
 		      break;
     }
@@ -2850,7 +2855,6 @@ static void SilentWalkTaggedFiles( int (*fkt) (/* ??? */),
 {
   FileEntry *fe_ptr;
   int       i;
-  int       result = 0;
 
   
   for( i=0; i < (int)file_count; i++ )
@@ -2859,7 +2863,7 @@ static void SilentWalkTaggedFiles( int (*fkt) (/* ??? */),
 
     if( fe_ptr->tagged && fe_ptr->matching )
     {
-      result = fkt( fe_ptr, walking_package );
+      (void)fkt( fe_ptr, walking_package );
     }
   }
 }
@@ -3035,3 +3039,106 @@ static void RereadWindowSize(DirEntry *dir_entry)
 }
 
 
+
+
+static void ListJump( DirEntry * dir_entry, char *str )
+{
+   int incremental = (!strcmp(LISTJUMPSEARCH, "1")) ? 1 : 0; /* from ~/.ytree */
+
+    /*  in file_window press initial char of file to jump to it */
+
+    char *newStr = NULL;
+    FileEntry * fe_ptr = NULL;
+    int i=0, j=0, n=0, start_x=0, ic=0, tmp2=0;
+    char * jumpmsg = "Press initial of file to jump to... ";
+
+    ClearHelp();
+    MvAddStr( LINES - 2, 1, jumpmsg );
+    PrintOptions
+    (
+        stdscr,
+        LINES - 2,
+        COLS - 14,
+        "(Escape) cancel"
+    );
+
+    ic = tolower(getch());
+
+    if( !isprint(ic) )
+    {
+        beep();
+        return;
+    }
+
+    n = strlen(str);
+    if((newStr = malloc(n+2)) == NULL) {
+      ERROR_MSG( "Malloc failed*ABORT" );
+      exit( 1 );
+    }
+    strcpy(newStr, str);
+    newStr[n] = ic;
+    newStr[n+1] = '\0';
+
+    /* index of current entry in list */
+    tmp2 = (incremental && n == 0) ? 0 : dir_entry->start_file + dir_entry->cursor_pos;
+
+    if( tmp2 == file_count - 1 )
+    {
+        ClearHelp();
+        MvAddStr( LINES - 2, 1, "Last entry!");
+        beep();
+        RefreshWindow( stdscr );
+        RefreshWindow( file_window );
+        doupdate();
+        sleep(1);
+        free(newStr);
+        return;
+    }
+
+    for( i=tmp2; i < file_count; i++ )
+    {
+        fe_ptr = file_entry_list[i].file;
+	if(!strncasecmp(newStr, fe_ptr->name, n+1))
+          break;
+    }
+
+    if ( i == file_count )
+    {
+        ClearHelp();
+        MvAddStr( LINES - 2, 1, "No match!");
+        beep();
+        RefreshWindow( stdscr );
+        RefreshWindow( file_window );
+        doupdate();
+        sleep(1);
+        free(newStr);
+        return;
+    }
+
+    /* position cursor on entry wanted and found */
+    if( incremental && n == 0 ) {
+      	/* first search start on top */
+      	dir_entry->start_file = 0;
+      	dir_entry->cursor_pos = 0;
+      	DisplayFiles( dir_entry, 
+            	dir_entry->start_file, 
+            	dir_entry->start_file + dir_entry->cursor_pos,
+            	start_x
+          	);
+    }
+    for ( j=tmp2; j < i; j++ )
+        fmovedown
+        (
+            &dir_entry->start_file,
+            &dir_entry->cursor_pos,
+            &start_x,
+            dir_entry
+        );
+    RefreshWindow( stdscr );
+    RefreshWindow( file_window );
+    doupdate();
+    ListJump( dir_entry, (incremental) ? newStr : "" );
+    free(newStr);
+} 
+
+
