@@ -1,6 +1,4 @@
 /***************************************************************************
- *
- * $Header: /usr/local/cvsroot/utils/ytree/history.c,v 1.5 2001/04/16 13:34:26 werner Exp $
  *
  * Functionkey F2 History
  *
@@ -108,7 +106,7 @@ void InsHistory( char *NewHst)
       {
          TMP -> next = Hist;
 	 TMP -> prev = NULL;
-	 if(( TMP -> hst = strdup(NewHst)) == NULL) 
+	 if(( TMP -> hst = Strdup(NewHst)) == NULL) 
 	 {
 	    free(TMP);
 	    return;
