@@ -17,9 +17,12 @@ char *StrLeft(const char *str, size_t count)
 #ifdef WITH_UTF8
   mbstate_t state;
 #endif
-  char *rez, *p, *tmp;
+  char *rez, *tmp;
   size_t len, i;
 
+#ifdef WITH_UTF8
+  memset(&state, 0, sizeof(state));
+#endif
   if (count == 0) return(Strdup(""));
   len = StrVisualLength(str);
   if (count >= len) return(Strdup(str));
@@ -27,14 +30,12 @@ char *StrLeft(const char *str, size_t count)
   len = 0;
 
   tmp = Strdup(str);
-  p = tmp; 
   for (i = 0; i < count; i++) {
 #ifdef WITH_UTF8
     len += mbrlen(p, 4, &state);
 #else
     len++;
 #endif
-    p = tmp + len;
   }
   free(tmp);
   
@@ -51,6 +52,10 @@ char *StrRight(const char *str, size_t count)
   char *rez, *p, *tmp;
   size_t byte_len, char_len, tmp_len, i;
 
+#ifdef WITH_UTF8
+  memset(&state, 0, sizeof(state));
+#endif
+
   if (count == 0) return(Strdup(""));
 
   byte_len = strlen(str);
@@ -83,9 +88,14 @@ int StrVisualLength(const char *str)
 {
 #ifdef WITH_UTF8
   mbstate_t state;
+  int len = 0;
   
   memset(&state, '\0', sizeof(state));
-  return(mbsrtowcs(NULL, &str, strlen(str), &state));
+  len = mbsrtowcs(NULL, &str, strlen(str), &state);
+  if(len < 0) {
+    /* Invalid multibyte sequence */
+    len = strlen(str);
+  }
 #else
   return(strlen(str));
 #endif
@@ -137,7 +147,7 @@ int InputString(char *s, int y, int x, int cursor_pos, int length, char *term)
 	  strcat(sbuf, buf);
 	}
       } else {
-        // Control symbols
+        /* Control symbols */
         switch( c1 )
         {
         case 'C' & 0x1f     : c1 = 27; 
@@ -254,16 +264,16 @@ int InputString(char *s, int y, int x, int cursor_pos, int length, char *term)
 
         default             : if( c1 == LF ) c1 = CR;
                               break;
-        } // switch
-      } // else control symbols
+        } /* switch */
+      } /* else control symbols */
     } else {
      
       if (strlen(sbuf) > 0) {
        if ( insert_flag ) {
-  	    // append symbol
+  	    /* append symbol */
 	    if ( p >= StrVisualLength(s)) strcat(s, sbuf);
 	    else {
-	      // insert symbol at cursor position
+	      /* insert symbol at cursor position */
 	      if ( p > 0 ) ls = StrLeft(s, p);
 	      else ls = Strdup("");
 	      rs = StrRight(s, StrVisualLength(s) - p);
@@ -274,7 +284,7 @@ int InputString(char *s, int y, int x, int cursor_pos, int length, char *term)
 	      free(rs);
 	    }
           } else {
-            // owerwrite symbol at cursor position
+            /* owerwrite symbol at cursor position */
 	    if ( p > StrVisualLength(s) - 1) strcat(s, sbuf);
 	    else {
   	      if (p > 0) ls = StrLeft(s, p);
@@ -337,7 +347,7 @@ int InputChoise(char *msg, char *term)
 
   curs_set(1);
   leaveok(stdscr, FALSE);
-  mvprintw( LINES - 2, 1, msg );
+  mvprintw( LINES - 2, 1, "%s", msg );
   RefreshWindow( stdscr );
   doupdate();
   do
