@@ -1,6 +1,4 @@
 /***************************************************************************
- *
- * $Header: /usr/local/cvsroot/utils/ytree/view.c,v 1.25 2004/12/30 18:55:32 werner Exp $
  *
  * View-Kommando-Bearbeitung
  *
@@ -70,7 +68,6 @@ static int ViewFile(DirEntry * dir_entry, char *file_path)
   char *command_line, *aux;
   int  compress_method;
   int  result = -1;
-  int  l;
   char *file_p_aux;
   BOOL notice_mapped = FALSE;
   char cwd[PATH_LENGTH+1];
@@ -114,7 +111,6 @@ static int ViewFile(DirEntry * dir_entry, char *file_path)
   else 
   {
     compress_method = GetFileMethod( file_path );
-    l = strlen( file_path );
     if( compress_method == FREEZE_COMPRESS )
     {
       (void) sprintf( command_line, 
@@ -185,7 +181,11 @@ the ytree starting cwd. new code grabbed from execute.c.
   	}else{
   		result = SystemCall(command_line);
   	}
-  	(void) chdir(cwd);  
+  	if( chdir(cwd) )
+	{
+  		(void) sprintf(message, "Can't change directory to*\"%s\"", cwd);
+  		MESSAGE(message);
+	}
   }else{
   	result = SystemCall(command_line);  
   }
@@ -219,7 +219,6 @@ static int ViewArchiveFile(char *file_path)
   char *command_line, *aux;
   char buffer[100];
   char *archive;
-  int  l;
   int  result = -1;
 
   if( ( command_line = malloc( COMMAND_LINE_LENGTH + 1 ) ) == NULL )
@@ -228,8 +227,6 @@ static int ViewArchiveFile(char *file_path)
     exit( 1 );
   }
 
-  l = strlen( file_path );
-  
   if (( aux = GetExtViewer(file_path)) != NULL) {
      if (strstr(aux,"%s") != NULL) {
   	(void) sprintf( buffer, "| %s", PAGER );
@@ -315,7 +312,7 @@ void printhexline(WINDOW *win, char *line, char *buf, int r, long offset)
 void update_line(WINDOW *win, long line)
 {
     int r;
-    unsigned char *buf;
+    char *buf;
     char *line_string;
     char mensaje[50];
 
@@ -574,13 +571,11 @@ void move_right(WINDOW *win)
 void hex_edit(char *file_path)
 {
     int ch;
-    long cursor_byte;
     char mensaje[50];
 
     BOOL QUIT=FALSE;
 
     cursor_pos_x = cursor_pos_y = 0;
-    cursor_byte = 0;
     fd2 = fd;
     fd=open(file_path,O_RDWR);
     if (fd == -1){
