@@ -1,6 +1,4 @@
 /***************************************************************************
- *
- * $Header: /usr/local/cvsroot/utils/ytree/ytree.h,v 1.44 2008/07/26 14:29:30 werner Exp $
  *
  * Header-Datei fuer YTREE
  *
@@ -10,7 +8,6 @@
 #define _LARGEFILE64_SOURCE 1
 #define _FILE_OFFSET_BITS 64                                                                   
 
-
 #include <stdio.h>
 #include <ctype.h>
 #include <math.h>
@@ -375,8 +372,10 @@ extern char *getcwd();
 #define VI_KEY_PPAGE ( 'U' & 0x1F )
 
 
-#define OWNER_NAME_MAX  14
-#define GROUP_NAME_MAX  14
+#define OWNER_NAME_MAX  64
+#define GROUP_NAME_MAX  64
+#define DISPLAY_OWNER_NAME_MAX  12
+#define DISPLAY_GROUP_NAME_MAX  12
 
 
 /* Sonderzeichen fuer Liniengrafik */
@@ -459,41 +458,42 @@ extern char *getcwd();
 /* Auswahl der benutzten UNIX-Kommandos */
 /*--------------------------------------*/
 
-#define CAT           GetProfileValue( "CAT" )
-#define HEXDUMP       GetProfileValue( "HEXDUMP" )
-#define EDITOR        GetProfileValue( "EDITOR" )
-#define PAGER         GetProfileValue( "PAGER" )
-#define MELT          GetProfileValue( "MELT" )
-#define UNCOMPRESS    GetProfileValue( "UNCOMPRESS" )
-#define GNUUNZIP      GetProfileValue( "GNUUNZIP" )
-#define BUNZIP        GetProfileValue( "BUNZIP" )
-#define MANROFF       GetProfileValue( "MANROFF" )
-#define TARLIST       GetProfileValue( "TARLIST" )
-#define TAREXPAND     GetProfileValue( "TAREXPAND" )
-#define RPMLIST       GetProfileValue( "RPMLIST" )
-#define RPMEXPAND     GetProfileValue( "RPMEXPAND" )
-#define ZOOLIST       GetProfileValue( "ZOOLIST" )
-#define ZOOEXPAND     GetProfileValue( "ZOOEXPAND" )
-#define ZIPLIST       GetProfileValue( "ZIPLIST" )
-#define ZIPEXPAND     GetProfileValue( "ZIPEXPAND" )
-#define LHALIST       GetProfileValue( "LHALIST" )
-#define LHAEXPAND     GetProfileValue( "LHAEXPAND" )
-#define ARCLIST       GetProfileValue( "ARCLIST" )
-#define ARCEXPAND     GetProfileValue( "ARCEXPAND" )
-#define TREEDEPTH     GetProfileValue( "TREEDEPTH" )
-#define USERVIEW      GetProfileValue( "USERVIEW" )
-#define RARLIST       GetProfileValue( "RARLIST" )
-#define RAREXPAND     GetProfileValue( "RAREXPAND" )
-#define FILEMODE      GetProfileValue( "FILEMODE" )
-#define NUMBERSEP     GetProfileValue( "NUMBERSEP" )
-#define NOSMALLWINDOW GetProfileValue( "NOSMALLWINDOW" )
-#define INITIALDIR    GetProfileValue( "INITIALDIR" )
-#define DIR1          GetProfileValue( "DIR1" )
-#define DIR2          GetProfileValue( "DIR2" )
-#define FILE1         GetProfileValue( "FILE1" )
-#define FILE2         GetProfileValue( "FILE2" )
-#define SEARCHCOMMAND GetProfileValue( "SEARCHCOMMAND" )
-#define HEXEDITOFFSET GetProfileValue( "HEXEDITOFFSET" )
+#define CAT             GetProfileValue( "CAT" )
+#define HEXDUMP         GetProfileValue( "HEXDUMP" )
+#define EDITOR          GetProfileValue( "EDITOR" )
+#define PAGER           GetProfileValue( "PAGER" )
+#define MELT            GetProfileValue( "MELT" )
+#define UNCOMPRESS      GetProfileValue( "UNCOMPRESS" )
+#define GNUUNZIP        GetProfileValue( "GNUUNZIP" )
+#define BUNZIP          GetProfileValue( "BUNZIP" )
+#define MANROFF         GetProfileValue( "MANROFF" )
+#define TARLIST         GetProfileValue( "TARLIST" )
+#define TAREXPAND       GetProfileValue( "TAREXPAND" )
+#define RPMLIST         GetProfileValue( "RPMLIST" )
+#define RPMEXPAND       GetProfileValue( "RPMEXPAND" )
+#define ZOOLIST         GetProfileValue( "ZOOLIST" )
+#define ZOOEXPAND       GetProfileValue( "ZOOEXPAND" )
+#define ZIPLIST         GetProfileValue( "ZIPLIST" )
+#define ZIPEXPAND       GetProfileValue( "ZIPEXPAND" )
+#define LHALIST         GetProfileValue( "LHALIST" )
+#define LHAEXPAND       GetProfileValue( "LHAEXPAND" )
+#define ARCLIST         GetProfileValue( "ARCLIST" )
+#define ARCEXPAND       GetProfileValue( "ARCEXPAND" )
+#define TREEDEPTH       GetProfileValue( "TREEDEPTH" )
+#define USERVIEW        GetProfileValue( "USERVIEW" )
+#define RARLIST         GetProfileValue( "RARLIST" )
+#define RAREXPAND       GetProfileValue( "RAREXPAND" )
+#define FILEMODE        GetProfileValue( "FILEMODE" )
+#define NUMBERSEP       GetProfileValue( "NUMBERSEP" )
+#define NOSMALLWINDOW   GetProfileValue( "NOSMALLWINDOW" )
+#define INITIALDIR      GetProfileValue( "INITIALDIR" )
+#define DIR1            GetProfileValue( "DIR1" )
+#define DIR2            GetProfileValue( "DIR2" )
+#define FILE1           GetProfileValue( "FILE1" )
+#define FILE2           GetProfileValue( "FILE2" )
+#define SEARCHCOMMAND   GetProfileValue( "SEARCHCOMMAND" )
+#define HEXEDITOFFSET   GetProfileValue( "HEXEDITOFFSET" )
+#define LISTJUMPSEARCH  GetProfileValue( "LISTJUMPSEARCH" )
  
 
 #define DEFAULT_TREE       "."
@@ -641,7 +641,7 @@ extern char *getcwd();
 
 #define DIR_WINDOW_X         1  
 #define DIR_WINDOW_Y         2 
-#define DIR_WINDOW_WIDTH     (COLS - 23)
+#define DIR_WINDOW_WIDTH     (COLS - 26)
 #define DIR_WINDOW_HEIGHT    ((LINES * 8 / 14)-1)
 
 #define F2_WINDOW_X          DIR_WINDOW_X
@@ -651,12 +651,12 @@ extern char *getcwd();
 
 #define FILE_WINDOW_1_X      1
 #define FILE_WINDOW_1_Y      DIR_WINDOW_HEIGHT + 3
-#define FILE_WINDOW_1_WIDTH  (COLS - 23)
+#define FILE_WINDOW_1_WIDTH  (COLS - 26)
 #define FILE_WINDOW_1_HEIGHT (LINES - DIR_WINDOW_HEIGHT - 7 )
 
 #define FILE_WINDOW_2_X      1
 #define FILE_WINDOW_2_Y      2
-#define FILE_WINDOW_2_WIDTH  (COLS - 23)
+#define FILE_WINDOW_2_WIDTH  (COLS - 26)
 #define FILE_WINDOW_2_HEIGHT (LINES - 6) 
 
 #define ERROR_WINDOW_WIDTH   40
@@ -666,15 +666,15 @@ extern char *getcwd();
 
 #define HISTORY_WINDOW_X       1
 #define HISTORY_WINDOW_Y       2
-#define HISTORY_WINDOW_WIDTH   (COLS - 23)
+#define HISTORY_WINDOW_WIDTH   (COLS - 26)
 #define HISTORY_WINDOW_HEIGHT  (LINES - 6)
 
 #define MATCHES_WINDOW_X       1
 #define MATCHES_WINDOW_Y       2
-#define MATCHES_WINDOW_WIDTH   (COLS - 23)
+#define MATCHES_WINDOW_WIDTH   (COLS - 26)
 #define MATCHES_WINDOW_HEIGHT  (LINES - 6)
 
-#define TIME_WINDOW_X        ((COLS > 18) ? (COLS - 18) : 1)
+#define TIME_WINDOW_X        ((COLS > 20) ? (COLS - 20) : 1)
 #define TIME_WINDOW_Y        1
 #define TIME_WINDOW_WIDTH    ((COLS > 15) ? 15 : COLS)
 #define TIME_WINDOW_HEIGHT   1
@@ -949,9 +949,11 @@ extern void SwitchToSmallFileWindow(void);
 extern void SwitchToBigFileWindow(void);
 extern int  ReadGroupEntries(void);
 extern char *GetGroupName(unsigned int gid);
+extern char *GetDisplayGroupName(unsigned int gid);
 extern int  GetGroupId(char *name);
 extern int  ReadPasswdEntries(void);
 extern char *GetPasswdName(unsigned int uid);
+extern char *GetDisplayPasswdName(unsigned int uid);
 extern int  GetPasswdUid(char *name);
 extern char *GetFileNamePath(FileEntry *file_entry, char *buffer);
 extern char *GetRealFileNamePath(FileEntry *file_entry, char *buffer);
@@ -1097,4 +1099,4 @@ extern char *StrLeft(const char *str, size_t count);
 extern int  StrVisualLength(const char *str);
 extern int  WAttrAddStr(WINDOW *win, int attr, char *str);
 extern char *Strndup(const char *s, int len);
-
+extern char *CutName(char *dest, char *src, unsigned int max_len);
